
# What is ydb-dstool

ydb-dstool stands for YDB Distributed Storage Tool. It facilitates administration of YDB storage.

# How to run ydb-dstool

## Install ydb-dstool package

```bash
user@host:~$ pip install ydb-dstool
```

## Set up environment and run

```bash
user@host:~$ export PATH=${PATH}:${HOME}/.local/bin
user@host:~$ ydb-dstool -e ydb.endpoint cluster list
```

# Where to find more info

https://github.com/ydb-platform/ydb/blob/main/ydb/apps/dstool/README.md
